pub struct ScrollbarConfig {
pub enabled: bool,
pub gap_left: u16,
pub gap_right: u16,
}Expand description
Scrollbar appearance configuration.
Fields
enabled: boolWhether the scrollbar is enabled.
gap_left: u16Columns of gap between the scrollbar and content (left side).
gap_right: u16Columns of gap between the scrollbar and the screen edge (right side).