Module renderable

Module renderable 

Measured ratatui cells used to compose the transcript and bottom pane.

Structs

Column
A vertical composition of independently measured views.
TextCell
A plain, wrapping text cell. Higher-level transcript cells can build styled Lines and delegate wrapping/measurement here.

Traits

Renderable
A view that can report its height before it is allocated a rectangle.