pub fn active_styles() -> ThemeStylesExpand description
Return a clone of the active style set. When a preview theme is active, returns the preview styles instead.
pub fn active_styles() -> ThemeStylesReturn a clone of the active style set. When a preview theme is active, returns the preview styles instead.