Module vim

Module vim 

Vim-style prompt editing engine for VT Code terminal surfaces.

Structs

HandleKeyOutcome
Result of routing a single key through the Vim engine.
VimState

Traits

Editor
Minimal text-editor surface required by the Vim engine.

Functions

handle_key
Apply a single key event to the Vim state and editor surface.
next_char_boundary
prev_char_boundary